@@ -34,7 +34,6 @@ def build(root, builder='html', **kwargs):
     confoverrides['html_theme'] = 'sphinx_rtd_theme'
     extensions = confoverrides.get('extensions', [])
     extensions.append('sphinx_rtd_theme')
-    extensions.append('readthedocs_ext.readthedocs')
     confoverrides['extensions'] = extensions
     kwargs['confoverrides'] = confoverrides
 
@@ -55,7 +54,6 @@ def build(root, builder='html', **kwargs):
 
 
 def build_all(root, **kwargs):
-    for builder in ['html', 'singlehtml', 'readthedocs', 'readthedocsdirhtml',
-                    'readthedocssinglehtml', 'readthedocssinglehtmllocalmedia']:
+    for builder in ['html', 'singlehtml']:
         with build(root, builder, **kwargs) as ret:
             yield ret
